-- ----------------------------
-- 部门信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_dept`;
CREATE TABLE mortals_xhx_dept(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键ID，主键，自增长',
    `parentId` bigint(20)      COMMENT '父id',
    `ancestors` varchar(256) NOT NULL     COMMENT '祖级列表',
    `deptName` varchar(256) NOT NULL     COMMENT '部门名称',
    `deptCode` varchar(256) NOT NULL     COMMENT '部门编码',
    `deptStatus` tinyint(2) NOT NULL   DEFAULT '1'  COMMENT '部门状态(0.停用,1.启用)',
    `orderNum` int(4) NOT NULL   DEFAULT '0'  COMMENT '顺序',
    `personNum` int(4) NOT NULL   DEFAULT '0'  COMMENT '部门人数',
    `workId` bigint(20)      COMMENT '负责人id',
    `workName` varchar(128)      COMMENT '负责人名称',
    `remark` varchar(256)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='部门信息';



-- ----------------------------
-- 员工基本信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff`;
CREATE TABLE mortals_xhx_staff(
                                  `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                  `name` varchar(64) NOT NULL     COMMENT '员工姓名',
                                  `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                  `birthday` datetime      COMMENT '出生日期',
                                  `photoPath` varchar(255)      COMMENT '照片',
                                  `phoneNumber` varchar(128)      COMMENT '联系电话',
                                  `idCard` varchar(128)      COMMENT '身份证号码',
                                  `workNum` varchar(128)      COMMENT '工号',
                                  `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 (1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                  `deptId` bigint(20)      COMMENT '所属部门',
                                  `deptName` varchar(128)      COMMENT '所属部门名称',
                                  `positionId` bigint(20)      COMMENT '职位ID',
                                  `positionName` varchar(128)      COMMENT '职位名称',
                                  `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型（1.全职,2.兼职,3.实习)',
                                  `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                  `registerPath` varchar(255)      COMMENT '入职登记表',
                                  `entryDate` datetime      COMMENT '入职时间',
                                  `regularDate` datetime      COMMENT '转正时间',
                                  `leaveDate` datetime      COMMENT '离职时间',
                                  `remark` varchar(255)      COMMENT '备注',
                                  `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                  `createTime` datetime NOT NULL     COMMENT '创建时间',
                                  `updateUserId` bigint(20)      COMMENT '更新用户',
                                  `updateTime` datetime      COMMENT '更新时间',
                                  `remarkId` varchar(255)      COMMENT '备注id',
                                  `source` tinyint(2)    DEFAULT '1'  COMMENT '员工来源(1.外部,2.内部)',
                                  PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工基本信息';




-- ----------------------------
-- 员工关怀信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_care`;
CREATE TABLE mortals_xhx_staff_care(
                                       `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                       `staffId` bigint(20)      COMMENT '员工ID',
                                       `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                       `birthday` datetime      COMMENT '出生日期',
                                       `deptId` bigint(20)      COMMENT '所属部门',
                                       `deptName` varchar(128)      COMMENT '所属部门名称',
                                       `jobId` bigint(20)      COMMENT '职位ID',
                                       `jobName` varchar(128)      COMMENT '职位名称',
                                       `entryDate` datetime      COMMENT '入职时间',
                                       `careType` tinyint(2)    DEFAULT '1'  COMMENT '关怀类型(1.生日关怀,2.入职周年关怀)',
                                       `sendStatus` tinyint(2)    DEFAULT '0'  COMMENT '发送状态(0.未发送,1.已发送)',
                                       `content` text      COMMENT '关怀内容',
                                       `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                       `createTime` datetime NOT NULL     COMMENT '创建时间',
                                       `updateUserId` bigint(20)      COMMENT '更新用户',
                                       `updateTime` datetime      COMMENT '更新时间',
                                       PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工关怀信息';

-- ----------------------------
-- 关怀问候信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_care_template`;
CREATE TABLE mortals_xhx_care_template(
                                          `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                          `careType` tinyint(2)    DEFAULT '1'  COMMENT '关怀类型(1.生日关怀,2.入职周年关怀)',
                                          `sms` tinyint(2)    DEFAULT '1'  COMMENT '是否短信提示(1.是,0.否)',
                                          `smsTemplate` text      COMMENT '短信模板内容',
                                          `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                          `createTime` datetime NOT NULL     COMMENT '创建时间',
                                          `updateUserId` bigint(20)      COMMENT '更新用户',
                                          `updateTime` datetime      COMMENT '更新时间',
                                          PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='关怀问候信息';

-- ----------------------------
-- 职位信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_job`;
CREATE TABLE mortals_xhx_job(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '主键，自增长',
    `groupId` bigint(20)      COMMENT '分组id',
    `groupName` varchar(128)      COMMENT '分组名称',
    `jobCode` varchar(128)      COMMENT '职位编码',
    `jobName` varchar(128)      COMMENT '职位名称',
    `remark` varchar(512)      COMMENT '备注',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
    `type` tinyint(2)    DEFAULT '1'  COMMENT '节点类型(1.分组,2.职位)',
PRIMARY KEY  (`id`)
,KEY `groupName` (`groupName`) USING BTREE
,KEY `jobCode` (`jobCode`) USING BTREE
,KEY `jobName` (`jobName`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='职位信息';


-- ----------------------------
-- 员工黑名单信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_black`;
CREATE TABLE mortals_xhx_staff_black(
                                        `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                        `staffId` bigint(20)      COMMENT '员工ID',
                                        `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                        `phoneNumber` varchar(128)      COMMENT '联系电话',
                                        `idCard` varchar(128)      COMMENT '身份证号码',
                                        `leaveDate` datetime      COMMENT '离职时间',
                                        `leaveReason` text      COMMENT '离职原因',
                                        `blackDate` datetime      COMMENT '拉黑时间',
                                        `blackReason` text      COMMENT '拉黑原因',
                                        `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                        `createTime` datetime NOT NULL     COMMENT '创建时间',
                                        `updateUserId` bigint(20)      COMMENT '更新用户',
                                        `updateTime` datetime      COMMENT '更新时间',
                                        PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工黑名单信息';

-- ----------------------------
-- 员工调岗信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_adjust_log`;
CREATE TABLE mortals_xhx_staff_adjust_log(
                                             `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                             `staffId` bigint(20)      COMMENT '员工ID',
                                             `fullName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                             `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别1男2女',
                                             `birthday` datetime      COMMENT '出生日期',
                                             `photoPath` varchar(255)      COMMENT '照片',
                                             `phoneNumber` varchar(128)      COMMENT '联系电话',
                                             `idCard` varchar(128)      COMMENT '身份证号码',
                                             `workNum` varchar(128)      COMMENT '工号',
                                             `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                             `deptId` bigint(20)      COMMENT '所属部门',
                                             `deptName` varchar(128)      COMMENT '所属部门名称',
                                             `jobId` bigint(20)      COMMENT '职位ID',
                                             `jobName` varchar(128)      COMMENT '职位名称',
                                             `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型1全职2兼职3实习',
                                             `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态1正式2试用3离职',
                                             `entryDate` datetime      COMMENT '入职时间',
                                             `newDeptId` bigint(20)      COMMENT '调岗后所属部门',
                                             `newDeptName` varchar(128)      COMMENT '调岗后所属部门名称',
                                             `newJobId` bigint(20)      COMMENT '调岗后职位ID',
                                             `newJobName` varchar(128)      COMMENT '调岗后职位名称',
                                             `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态0待审核1通过2拒绝',
                                             `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                             `createTime` datetime NOT NULL     COMMENT '创建时间',
                                             `updateUserId` bigint(20)      COMMENT '更新用户',
                                             `updateTime` datetime      COMMENT '更新时间',
                                             PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工调岗信息';

-- ----------------------------
-- 员工转正信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_regular`;
CREATE TABLE mortals_xhx_staff_regular(
                                          `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                          `staffId` bigint(20)      COMMENT '员工ID',
                                          `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                          `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                          `birthday` datetime      COMMENT '出生日期',
                                          `photoPath` varchar(255)      COMMENT '照片',
                                          `phoneNumber` varchar(128)      COMMENT '联系电话',
                                          `idCard` varchar(128)      COMMENT '身份证号码',
                                          `workNum` varchar(128)      COMMENT '工号',
                                          `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                          `deptId` bigint(20)      COMMENT '所属部门',
                                          `deptName` varchar(128)      COMMENT '所属部门名称',
                                          `jobId` bigint(20)      COMMENT '职位ID',
                                          `jobName` varchar(128)      COMMENT '职位名称',
                                          `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                          `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                          `entryDate` datetime      COMMENT '入职时间',
                                          `regularDate` datetime      COMMENT '计划转正时间',
                                          `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审核,1.通过,2.拒绝)',
                                          `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                          `createTime` datetime NOT NULL     COMMENT '创建时间',
                                          `updateUserId` bigint(20)      COMMENT '更新用户',
                                          `updateTime` datetime      COMMENT '更新时间',
                                          PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工转正信息';

-- ----------------------------
-- 员工离职信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_leave`;
CREATE TABLE mortals_xhx_staff_leave(
                                        `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                        `staffId` bigint(20)      COMMENT '员工ID',
                                        `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                        `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                        `birthday` datetime      COMMENT '出生日期',
                                        `photoPath` varchar(255)      COMMENT '照片',
                                        `phoneNumber` varchar(128)      COMMENT '联系电话',
                                        `idCard` varchar(128)      COMMENT '身份证号码',
                                        `workNum` varchar(128)      COMMENT '工号',
                                        `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                        `deptId` bigint(20)      COMMENT '所属部门',
                                        `deptName` varchar(128)      COMMENT '所属部门名称',
                                        `jobId` bigint(20)      COMMENT '职位ID',
                                        `jobName` varchar(128)      COMMENT '职位名称',
                                        `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                        `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                        `entryDate` datetime      COMMENT '入职时间',
                                        `leaveDate` datetime      COMMENT '离职时间',
                                        `leaveReason` text      COMMENT '离职原因',
                                        `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审,1.通过,2.拒绝)',
                                        `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                        `createTime` datetime NOT NULL     COMMENT '创建时间',
                                        `updateUserId` bigint(20)      COMMENT '更新用户',
                                        `updateTime` datetime      COMMENT '更新时间',
                                        PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工离职信息';

-- ----------------------------
-- 员工合同信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_staff_contract`;
CREATE TABLE mortals_xhx_staff_contract(
                                           `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                           `staffId` bigint(20)      COMMENT '员工ID',
                                           `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                           `gender` tinyint(2)    DEFAULT '1'  COMMENT '性别(1.男,2.女)',
                                           `birthday` datetime      COMMENT '出生日期',
                                           `photoPath` varchar(255)      COMMENT '照片',
                                           `phoneNumber` varchar(128)      COMMENT '联系电话',
                                           `idCard` varchar(128)      COMMENT '身份证号码',
                                           `workNum` varchar(128)      COMMENT '工号',
                                           `politicalstatus` tinyint(2)    DEFAULT '1'  COMMENT '政治面貌 （1.中共党员，2.中共预备党员，3.共青团员，4.群众，5.其它)',
                                           `deptId` bigint(20)      COMMENT '所属部门',
                                           `deptName` varchar(128)      COMMENT '所属部门名称',
                                           `jobId` bigint(20)      COMMENT '职位ID',
                                           `jobName` varchar(128)      COMMENT '职位名称',
                                           `staffType` tinyint(2)    DEFAULT '1'  COMMENT '员工类型(1.全职,2.兼职,3.实习)',
                                           `status` tinyint(2)    DEFAULT '1'  COMMENT '员工状态(1.正式,2.试用,3.离职)',
                                           `entryDate` datetime      COMMENT '入职时间',
                                           `contractStartDate` datetime      COMMENT '现合同开始时间',
                                           `contractEndDate` datetime      COMMENT '现合同到期时间',
                                           `contractCompany` varchar(255)      COMMENT '合同公司',
                                           `contractType` tinyint(2)    DEFAULT '1'  COMMENT '合同类型(1.纸质)',
                                           `newStartDate` datetime      COMMENT '新合同开始时间',
                                           `newEndDate` datetime      COMMENT '新合同到期时间',
                                           `auditStatus` tinyint(2)    DEFAULT '0'  COMMENT '审核状态(0.待审核,1.通过,2.拒绝)',
                                           `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                           `createTime` datetime NOT NULL     COMMENT '创建时间',
                                           `updateUserId` bigint(20)      COMMENT '更新用户',
                                           `updateTime` datetime      COMMENT '更新时间',
                                           PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工合同信息';

-- ----------------------------
-- 考勤打卡记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record`;
CREATE TABLE mortals_xhx_attendance_record(
                                              `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                              `staffId` bigint(20)      COMMENT '员工ID',
                                              `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
                                              `workNum` varchar(128)      COMMENT '工号',
                                              `deptId` bigint(20)      COMMENT '所属部门',
                                              `deptName` varchar(128)      COMMENT '所属部门名称',
                                              `positionId` bigint(20)      COMMENT '职位ID',
                                              `positionName` varchar(128)      COMMENT '职位名称',
                                              `attendanceGroupId` bigint(20)      COMMENT '所属考勤组ID',
                                              `attendanceGroupName` varchar(128)      COMMENT '所属考勤组名称',
                                              `shiftsId` bigint(20)      COMMENT '班次ID',
                                              `shiftsName` varchar(128)      COMMENT '班次名称',
                                              `attendanceDate` datetime      COMMENT '打卡日期',
                                              `remark` varchar(255)      COMMENT '备注',
                                              `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
                                              `createTime` datetime NOT NULL     COMMENT '创建时间',
                                              `updateUserId` bigint(20)      COMMENT '更新用户',
                                              `updateTime` datetime      COMMENT '更新时间',
                                              PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤打卡记录信息';

-- ----------------------------
-- 考勤打卡记录详细信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record_detail`;
CREATE TABLE mortals_xhx_attendance_record_detail(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `recordId` bigint(20)      COMMENT '考勤记录ID',
    `shiftsId` bigint(20)      COMMENT '班次ID',
    `shiftsName` varchar(128)      COMMENT '班次名称',
    `goWorkDate` datetime      COMMENT '上班打卡时间',
    `goWorkResult` tinyint(2)      COMMENT '上班打卡结果(1.正常,2.请假,3.缺卡,4.迟到,5.早退)',
    `offWorkDate` datetime      COMMENT '下班打卡时间',
    `offWorkResult` tinyint(2)      COMMENT '下班打卡结果(1.正常,2.请假,3.缺卡,4.迟到,5.早退)',
    `remark` varchar(255)      COMMENT '备注',
    `orderNum` int(4)    DEFAULT '1'  COMMENT '排序字段',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤打卡记录详细信息';



-- ----------------------------
-- 请假记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_leave_record`;
CREATE TABLE mortals_xhx_attendance_leave_record(
                                                    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
                                                    `leavePersonId` bigint(20) NOT NULL     COMMENT '请假人id',
                                                    `leavePerson` varchar(64)      COMMENT '请假人',
                                                    `deptId` bigint(20)      COMMENT '所属部门id',
                                                    `deptName` varchar(256)      COMMENT '所属部门',
                                                    `phoneNumber` varchar(20)      COMMENT '电话号码',
                                                    `leaveType` tinyint(2)      COMMENT '请假类型(1.事假,2.调休,3.病假,4.年假,5.产假,6.陪产假,7.婚假,8.例假,9.哺乳假,10.丧假)',
                                                    `startTime` datetime      COMMENT '开始时间',
                                                    `endTime` datetime      COMMENT '结束时间',
                                                    `duration` int(9)      COMMENT '时长,单位秒',
                                                    `reason` text      COMMENT '请假事由',
                                                    `approverId` bigint(20)      COMMENT '审批负责人Id',
                                                    `approver` varchar(64)      COMMENT '审批负责人',
                                                    `attachment` varchar(255)      COMMENT '附件',
                                                    `attachmentPath` varchar(255)      COMMENT '附件路径',
                                                    `remark` varchar(255)      COMMENT '备注',
                                                    `createUserId` bigint(20)      COMMENT '创建用户',
                                                    `createTime` datetime      COMMENT '创建时间',
                                                    `updateUserId` bigint(20)      COMMENT '更新用户',
                                                    `updateTime` datetime      COMMENT '更新时间',
                                                    PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='请假记录信息';

-- ----------------------------
-- 员工假期余额信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_vacation_balance`;
CREATE TABLE mortals_xhx_attendance_vacation_balance(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '员工id',
    `staffName` varchar(255)      COMMENT '员工姓名',
    `deptId` bigint(20)      COMMENT '部门id',
    `deptName` varchar(255)      COMMENT '部门名称',
    `entryTime` datetime      COMMENT '入职时间',
    `personalLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '事假（天）',
    `compensatedLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '调休（天）',
    `sickLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '病假（天）',
    `annualLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '年假（天）',
    `maternityLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '产假（天）',
    `paternityLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '陪产假（天）',
    `marriageLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '婚假（天）',
    `menstrualLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '例假（天）',
    `breastfeedingLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '哺乳假（天）',
    `bereavementLeaveDays` decimal(10,2)    DEFAULT '0'  COMMENT '丧假（天）',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工假期余额信息';

-- ----------------------------
-- 员工假期记录信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_vacation_record`;
CREATE TABLE mortals_xhx_attendance_vacation_record(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '员工id',
    `staffName` varchar(255)      COMMENT '员工姓名',
    `type` tinyint(2)      COMMENT '请假类型(1.事假,2.调休,3.病假,4.年假,5.产假,6.陪产假,7.婚假,8.例假,9.哺乳假,10.丧假)',
    `subAddType` tinyint(1)    DEFAULT '1'  COMMENT '增减类型(1.增加,2.扣除)',
    `validityPeriod` varchar(255)    DEFAULT '0'  COMMENT '有效期',
    `subOrAddDays` decimal(10,2)    DEFAULT '0'  COMMENT '增加或扣减天数（天）',
    `content` varchar(255)      COMMENT '内容',
    `rule` varchar(255)      COMMENT '规则',
    `reason` varchar(255)      COMMENT '理由',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `createTime` datetime      COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='员工假期记录信息';


-- ----------------------------
-- 考勤人员汇总信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_staff_stat`;
CREATE TABLE mortals_xhx_attendance_staff_stat(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
    `attendanceSummary` varchar(512) NOT NULL     COMMENT '考勤汇总信息，如迟到*1,旷工*2等',
    `year` int(9) NOT NULL     COMMENT '年',
    `month` int(9) NOT NULL     COMMENT '月',
    `day` int(9) NOT NULL     COMMENT '日',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤人员汇总信息';

-- ----------------------------
-- 考勤汇总信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_stat`;
CREATE TABLE mortals_xhx_attendance_stat(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `windowCategory` varchar(50) NOT NULL     COMMENT '窗口类别',
    `staffId` bigint(20)      COMMENT '员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
    `deptId` bigint(20)      COMMENT '所属部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `backToUnit` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '回单位（天）',
    `onDutyLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '因公请假（天）',
    `outOfOffice` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '外出勘验（天）',
    `shiftCompensation` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '值班补班（天）',
    `physicalExamination` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '体检（天）',
    `quarantine` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '隔离（天）',
    `businessTrip` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '因公外出（与窗口工作无关/天）',
    `publicHoliday` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '公休（天）',
    `sickLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '病假（天）',
    `funeralLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '丧假（天）',
    `marriageLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '婚假（天）',
    `childRearingLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '育儿假（天）',
    `maternityLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '产假（陪护假/天）',
    `transferBack` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '调回单位（或离职/天）',
    `homeLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '探亲假（天）',
    `personalLeave` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '事假（天）',
    `absenteeismDays` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '考勤汇总-旷工（天）',
    `otherDays` double(4,1) NOT NULL   DEFAULT '0.0'  COMMENT '考勤汇总-其他（天）',
    `attendanceRate` double(4,2) NOT NULL   DEFAULT '0.00'  COMMENT '考勤汇总-出勤率（%）',
    `nonCompliancePunch` double(4,1) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-未按规定打卡（含忘记打卡）',
    `lateTimes` int(9) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-迟到（次）',
    `surfingMobileTimes` int(9) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-上网耍手机（次）',
    `overtimeTimes` int(9) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-溜班（次）',
    `vacancy` double(4,1) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-空岗',
    `nonStandardDressTimes` int(9) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-未规范着装（次）',
    `unexcusedMeetingAbsence` double(4,1) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-无故缺席会议',
    `earlyLeaveMeeting` double(4,1) NOT NULL   DEFAULT '0'  COMMENT '考勤汇总-会议早退',
    `year` int(9) NOT NULL     COMMENT '年',
    `month` int(9) NOT NULL     COMMENT '月',
    `day` int(9) NOT NULL     COMMENT '日',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤汇总信息';

-- ----------------------------
-- 考勤打卡记录异常信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record_error`;
CREATE TABLE mortals_xhx_attendance_record_error(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
    `workNum` varchar(128)      COMMENT '工号',
    `deptId` bigint(20)      COMMENT '所属部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `positionId` bigint(20)      COMMENT '职位ID',
    `positionName` varchar(128)      COMMENT '职位名称',
    `attendanceGroupId` bigint(20)      COMMENT '所属考勤组ID',
    `attendanceGroupName` varchar(128)      COMMENT '所属考勤组名称',
    `shiftsId` bigint(20)      COMMENT '班次ID',
    `shiftsName` varchar(128)      COMMENT '班次名称',
    `goOffDateTime` datetime      COMMENT '上下班时间',
    `errorDateTime` datetime      COMMENT '异常时间',
    `actualAttendanceDateTime` datetime      COMMENT '实际打卡时间',
    `operDateTime` datetime      COMMENT '处理时间',
    `opertor` varchar(128)      COMMENT '处理人',
    `errorStatus` tinyint(2)    DEFAULT '0'  COMMENT '异常状态(0.缺卡,1.早退,2.迟到)',
    `processStatus` tinyint(2)    DEFAULT '0'  COMMENT '处理状态(0.未处理,1.已处理)',
    `processResult` varchar(128)      COMMENT '处理结果',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤打卡记录异常信息';

-- ----------------------------
-- 海康考勤打卡记录汇总信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_record_hik`;
CREATE TABLE mortals_xhx_attendance_record_hik(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `staffId` bigint(20)      COMMENT '员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
    `workNum` varchar(128)      COMMENT '工号',
    `deptId` bigint(20)      COMMENT '所属部门',
    `deptName` varchar(128)      COMMENT '所属部门名称',
    `positionId` bigint(20)      COMMENT '职位ID',
    `positionName` varchar(128)      COMMENT '职位名称',
    `attendanceGroupId` bigint(20)      COMMENT '所属考勤组ID',
    `attendanceGroupName` varchar(128)      COMMENT '所属考勤组名称',
    `shiftsId` bigint(20)      COMMENT '班次ID',
    `shiftsName` varchar(128)      COMMENT '班次名称',
    `attendanceDate` datetime      COMMENT '考勤日期',
    `attendanceAddress` varchar(128)      COMMENT '考勤点名称',
    `eventSource` varchar(128)      COMMENT '事件源',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='海康考勤打卡记录汇总信息';

-- ----------------------------
-- 工作人员表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_workman`;
CREATE TABLE mortals_xhx_workman(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `deptId` bigint(20)    DEFAULT '0'  COMMENT '部门id号',
    `deptName` varchar(64)      COMMENT '部门名称',
    `name` varchar(64)      COMMENT '姓名',
    `number` varchar(64)      COMMENT '工号',
    `phone` varchar(64)      COMMENT '电话号码',
    `photoPath` varchar(255)      COMMENT '照片',
    `createTime` datetime      COMMENT '创建时间',
    `createUserId` bigint(20)      COMMENT '创建用户',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '修改时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='工作人员';

-- ----------------------------
-- 考勤班次详细信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_class_detail`;
CREATE TABLE mortals_xhx_attendance_class_detail(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `classId` bigint(20)      COMMENT '班次ID',
    `className` varchar(128)      COMMENT '班次名称',
    `goWorkDate` datetime      COMMENT '上班打卡时间',
    `goWorkDateBefore` int(9)      COMMENT '上班打卡前时间段,单位分钟',
    `goWorkDateAfter` int(9)      COMMENT '上班打卡前时间段,单位分钟',
    `offWorkDate` datetime      COMMENT '下班打卡时间',
    `offWorkDateBefore` int(9)      COMMENT '下班打卡前时间段,单位分钟',
    `offWorkDateAfter` int(9)      COMMENT '下班打卡前时间段,单位分钟',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤班次详细信息';

-- ----------------------------
-- 考勤班次信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_class`;
CREATE TABLE mortals_xhx_attendance_class(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `className` varchar(128)      COMMENT '班次名称',
    `classResponsiblePersonId` bigint(20)      COMMENT '班次负责人ID',
    `classResponsiblePersonName` varchar(128)      COMMENT '班次负责人名称',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤班次信息';

-- ----------------------------
-- 考勤组考勤自由工时特殊日期配置表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_freework_special`;
CREATE TABLE mortals_xhx_attendance_group_freework_special(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `freeWorkId` bigint(20)      COMMENT '自由工时考勤配置id',
    `must` tinyint(1)    DEFAULT '0'  COMMENT '是否必须打卡的日期，当为1时有班次相关信息，否则有无需打卡时间段信息(0.否,1.是)',
    `classId` bigint(20)      COMMENT '班次ID',
    `className` varchar(128)      COMMENT '班次名称',
    `addWay` tinyint(1)    DEFAULT '0'  COMMENT '无需打卡的日期类型(0.单个日期,1.时间段)',
    `specialTime` datetime NOT NULL     COMMENT '特殊时间',
    `specialStartTime` datetime NOT NULL     COMMENT '时间段时候开始时间',
    `specialEndTime` datetime NOT NULL     COMMENT '时间段结束时间',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',

PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组考勤自由工时特殊日期配置';



-- ----------------------------
-- 考勤组考勤自由工时配置表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_freework`;
CREATE TABLE mortals_xhx_attendance_group_freework(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `groupId` bigint(20)      COMMENT '考勤组',
    `groupName` varchar(128)      COMMENT '考勤组名称',
    `monday` tinyint(1)    DEFAULT '0'  COMMENT '周一是否考勤(0.否,1.是)',
    `tuesday` tinyint(1)    DEFAULT '0'  COMMENT '周二是否考勤(0.否,1.是)',
    `wednesday` tinyint(1)    DEFAULT '0'  COMMENT '周三是否考勤(0.否,1.是)',
    `thursday` tinyint(1)    DEFAULT '0'  COMMENT '周四是否考勤(0.否,1.是)',
    `friday` tinyint(1)    DEFAULT '0'  COMMENT '周五是否考勤(0.否,1.是)',
    `saturday` tinyint(1)    DEFAULT '0'  COMMENT '周六是否考勤(0.否,1.是)',
    `sunday` tinyint(1)    DEFAULT '0'  COMMENT '周日是否考勤(0.否,1.是)',
    `holidays` tinyint(1)    DEFAULT '1'  COMMENT '法定节假日自动排休(0.否,1.是)',
    `workTime` int(4)    DEFAULT '0'  COMMENT '工作时长，单位小时',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组考勤自由工时配置';

-- ----------------------------
-- 考勤组考勤固定班制特殊日期配置表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_fixedwork_special`;
CREATE TABLE mortals_xhx_attendance_group_fixedwork_special(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `fixedWorkId` bigint(20)      COMMENT '固定班制考勤配置id',
    `must` tinyint(1)    DEFAULT '0'  COMMENT '是否必须打卡的日期，当为1时有班次相关信息，否则有无需打卡时间段信息(0.否,1.是)',
    `classId` bigint(20)      COMMENT '班次ID',
    `className` varchar(128)      COMMENT '班次名称',
    `addWay` tinyint(1)    DEFAULT '0'  COMMENT '无需打卡的日期类型(0.单个日期,1.时间段)',
    `specialTime` datetime NOT NULL     COMMENT '特殊时间',
    `specialStartTime` datetime NOT NULL     COMMENT '时间段时候开始时间',
    `specialEndTime` datetime NOT NULL     COMMENT '时间段结束时间',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组考勤固定班制特殊日期配置';



-- ----------------------------
-- 考勤组考勤固定工时表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_fixedwork`;
CREATE TABLE mortals_xhx_attendance_group_fixedwork(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `groupId` bigint(20)      COMMENT '考勤组',
    `groupName` varchar(128)      COMMENT '考勤组名称',
    `monday` tinyint(1)    DEFAULT '0'  COMMENT '周一是否考勤(0.否,1.是)',
    `mondayClassId` bigint(20)      COMMENT '周一班次ID',
    `mondayClassName` varchar(128)      COMMENT '周一班次名称',
    `tuesday` tinyint(1)    DEFAULT '0'  COMMENT '周二是否考勤(0.否,1.是)',
    `tuesdayClassId` bigint(20)      COMMENT '周二班次ID',
    `tuesdayClassName` varchar(128)      COMMENT '周二班次名称',
    `wednesday` tinyint(1)    DEFAULT '0'  COMMENT '周三是否考勤(0.否,1.是)',
    `wednesdayClassId` bigint(20)      COMMENT '周三班次ID',
    `wednesdayClassName` varchar(128)      COMMENT '周三班次名称',
    `thursday` tinyint(1)    DEFAULT '0'  COMMENT '周四是否考勤(0.否,1.是)',
    `thursdayClassId` bigint(20)      COMMENT '周四班次ID',
    `thursdayClassName` varchar(128)      COMMENT '周四班次名称',
    `friday` tinyint(1)    DEFAULT '0'  COMMENT '周五是否考勤(0.否,1.是)',
    `fridayClassId` bigint(20)      COMMENT '周五班次ID',
    `fridayClassName` varchar(128)      COMMENT '周五班次名称',
    `saturday` tinyint(1)    DEFAULT '0'  COMMENT '周六是否考勤(0.否,1.是)',
    `saturdayClassId` bigint(20)      COMMENT '周六班次ID',
    `saturdayClassName` varchar(128)      COMMENT '周六班次名称',
    `sunday` tinyint(1)    DEFAULT '0'  COMMENT '周日是否考勤(0.否,1.是)',
    `sundayClassId` bigint(20)      COMMENT '周日班次ID',
    `sundayClassName` varchar(128)      COMMENT '周日班次名称',
    `holidays` tinyint(1)    DEFAULT '1'  COMMENT '法定节假日自动排休(0.否,1.是)',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组考勤固定工时';

-- ----------------------------
-- 考勤组人员信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_staff`;
CREATE TABLE mortals_xhx_attendance_group_staff(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `groupId` bigint(20)      COMMENT '考勤组',
    `groupName` varchar(128)      COMMENT '考勤组名称',
    `staffId` bigint(20)      COMMENT '员工ID',
    `staffName` varchar(64) NOT NULL     COMMENT '员工姓名',
    `partAttendance` tinyint(2)      COMMENT '是否参与考勤，(0.否,1.是)',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组人员信息';

-- ----------------------------
-- 考勤组负责人员信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group_responsible`;
CREATE TABLE mortals_xhx_attendance_group_responsible(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `groupId` bigint(20)      COMMENT '考勤组',
    `groupName` varchar(128)      COMMENT '考勤组名称',
    `responsibleId` bigint(20)      COMMENT '负责人ID',
    `responsibleName` varchar(64) NOT NULL     COMMENT '负责人名称',
    `responsibleType` tinyint(2)      COMMENT '负责人类型(0. 主负责人,1. 子负责人)',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组负责人员信息';

-- ----------------------------
-- 考勤组信息表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_attendance_group`;
CREATE TABLE mortals_xhx_attendance_group(
    `id` bigint(20)   AUTO_INCREMENT   COMMENT '序号，主键，自增长',
    `groupName` varchar(128)      COMMENT '考勤组名称',
    `personNum` int(9)      COMMENT '参与考勤人数',
    `type` tinyint(2)      COMMENT '类型(1.固定班制,2.排班制,3.自由工时)',
    `remark` varchar(255)      COMMENT '备注',
    `createUserId` bigint(20) NOT NULL     COMMENT '创建用户',
    `createTime` datetime NOT NULL     COMMENT '创建时间',
    `updateUserId` bigint(20)      COMMENT '更新用户',
    `updateTime` datetime      COMMENT '更新时间',
    `personNumNo` int(9)      COMMENT '未参与考勤人数',
    `attendanceType` varchar(256)      COMMENT '考勤方式(地点打卡. 地点打卡, Wi-Fi打卡. Wi-Fi打卡, 蓝牙打卡. 蓝牙打卡, 考勤机打卡. 考勤机打卡)',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='考勤组信息';







